// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package ods

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	svr "LAPP_LF_MOM_BACKEND/services/ods"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 09:38:27
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块ods路由分组
	grmi.RegisterRouteMapping("/ods", func(party router.Party) {

		// OdsType的路由组
		odstype := party.Party("/odstype")
		// OdsType的服务实例
		var serviceOfOdsType = svr.NewOdsTypeService()
		// OdsType插入一条
		RegisterInsertOneOdsType(odstype, "/insertone", serviceOfOdsType.InsertOne)
		// OdsType插入多条
		// RegisterInsertOdsType(odstype, "/insert", serviceOfOdsType.Insert)
		// OdsType删除一条
		RegisterDeleteOneOdsType(odstype, "/deleteone", serviceOfOdsType.DeleteOne)
		// OdsType删除多条
		// RegisterDeleteOdsType(odstype, "/delete", serviceOfOdsType.Delete)
		// OdsType查询多条
		RegisterSelectOdsType(odstype, "/query", serviceOfOdsType.Select)
		// OdsType查询一条
		RegisterSelectOneOdsType(odstype, "/get", serviceOfOdsType.SelectOne)
		// OdsType修改一条
		RegisterUpdateOneOdsType(odstype, "/updateone", serviceOfOdsType.UpdateOne)
		// OdsType修改多条
		// RegisterUpdateOdsType(odstype, "/update", serviceOfOdsType.Update)

		// OdsHead的路由组
		odshead := party.Party("/odshead")
		// OdsHead的服务实例
		var serviceOfOdsHead = svr.NewOdsHeadService()
		// OdsHead插入一条
		RegisterInsertOneOdsHead(odshead, "/insertone", serviceOfOdsHead.InsertOne)
		// OdsHead插入多条
		// RegisterInsertOdsHead(odshead, "/insert", serviceOfOdsHead.Insert)
		// OdsHead删除一条
		RegisterDeleteOneOdsHead(odshead, "/deleteone", serviceOfOdsHead.DeleteOne)
		// OdsHead删除多条
		// RegisterDeleteOdsHead(odshead, "/delete", serviceOfOdsHead.Delete)
		// OdsHead查询多条
		RegisterSelectOdsHead(odshead, "/query", serviceOfOdsHead.Select)
		// OdsHead查询一条
		RegisterSelectOneOdsHead(odshead, "/get", serviceOfOdsHead.SelectOne)
		// OdsHead修改一条
		RegisterUpdateOneOdsHead(odshead, "/updateone", serviceOfOdsHead.UpdateOne)
		// OdsHead修改多条
		// RegisterUpdateOdsHead(odshead, "/update", serviceOfOdsHead.Update)

		// OdsStepLst的路由组
		odssteplst := party.Party("/odssteplst")
		// OdsStepLst的服务实例
		var serviceOfOdsStepLst = svr.NewOdsStepLstService()
		// OdsStepLst插入一条
		// RegisterInsertOneOdsStepLst(odssteplst, "/insertone", serviceOfOdsStepLst.InsertOne)
		// OdsStepLst插入多条
		// RegisterInsertOdsStepLst(odssteplst, "/insert", serviceOfOdsStepLst.Insert)
		// OdsStepLst删除一条
		// RegisterDeleteOneOdsStepLst(odssteplst, "/deleteone", serviceOfOdsStepLst.DeleteOne)
		// OdsStepLst删除多条
		// RegisterDeleteOdsStepLst(odssteplst, "/delete", serviceOfOdsStepLst.Delete)
		// OdsStepLst查询多条
		RegisterSelectOdsStepLst(odssteplst, "/query", serviceOfOdsStepLst.Select)
		// OdsStepLst查询一条
		RegisterSelectOneOdsStepLst(odssteplst, "/get", serviceOfOdsStepLst.SelectOne)
		// OdsStepLst修改一条
		// RegisterUpdateOneOdsStepLst(odssteplst, "/updateone", serviceOfOdsStepLst.UpdateOne)
		// OdsStepLst修改多条
		// RegisterUpdateOdsStepLst(odssteplst, "/update", serviceOfOdsStepLst.Update)

		// ArtRouteOdsLst的路由组
		artrouteodslst := party.Party("/artrouteodslst")
		// ArtRouteOdsLst的服务实例
		var serviceOfArtRouteOdsLst = svr.NewArtRouteOdsLstService()
		// ArtRouteOdsLst插入一条
		RegisterInsertOneArtRouteOdsLst(artrouteodslst, "/insertone", serviceOfArtRouteOdsLst.InsertOne)
		// ArtRouteOdsLst插入多条
		// RegisterInsertArtRouteOdsLst(artrouteodslst, "/insert", serviceOfArtRouteOdsLst.Insert)
		// ArtRouteOdsLst删除一条
		RegisterDeleteOneArtRouteOdsLst(artrouteodslst, "/deleteone", serviceOfArtRouteOdsLst.DeleteOne)
		// ArtRouteOdsLst删除多条
		// RegisterDeleteArtRouteOdsLst(artrouteodslst, "/delete", serviceOfArtRouteOdsLst.Delete)
		// ArtRouteOdsLst查询多条
		RegisterSelectArtRouteOdsLst(artrouteodslst, "/query", serviceOfArtRouteOdsLst.Select)
		// ArtRouteOdsLst查询一条
		RegisterSelectOneArtRouteOdsLst(artrouteodslst, "/get", serviceOfArtRouteOdsLst.SelectOne)
		// ArtRouteOdsLst查询byplaceid
		RegisterSelectOneArtRouteOdsLstByWorkPlaceId(artrouteodslst, "/getbyplaceid", serviceOfArtRouteOdsLst.SelectOneByWorkPlaceId)
		// ArtRouteStepOdsLst查询多条,通过物料号
		RegisterSelectOneArtRouteOdsLstByArtId(artrouteodslst, "/selectbyartid", serviceOfArtRouteOdsLst.SelectByArtId)
		// ArtRouteOdsLst修改一条
		RegisterUpdateOneArtRouteOdsLst(artrouteodslst, "/updateone", serviceOfArtRouteOdsLst.UpdateOne)
		// ArtRouteOdsLst修改多条
		// RegisterUpdateArtRouteOdsLst(artrouteodslst, "/update", serviceOfArtRouteOdsLst.Update)

		// ArtRouteStepOdsLst的路由组
		artroutestepodslst := party.Party("/artroutestepodslst")
		// ArtRouteStepOdsLst的服务实例
		var serviceOfArtRouteStepOdsLst = svr.NewArtRouteStepOdsLstService()
		// ArtRouteStepOdsLst插入一条
		// RegisterInsertOneArtRouteStepOdsLst(artroutestepodslst, "/insertone", serviceOfArtRouteStepOdsLst.InsertOne)
		// ArtRouteStepOdsLst插入多条
		// RegisterInsertArtRouteStepOdsLst(artroutestepodslst, "/insert", serviceOfArtRouteStepOdsLst.Insert)
		// ArtRouteStepOdsLst删除一条
		// RegisterDeleteOneArtRouteStepOdsLst(artroutestepodslst, "/deleteone", serviceOfArtRouteStepOdsLst.DeleteOne)
		// ArtRouteStepOdsLst删除多条
		// RegisterDeleteArtRouteStepOdsLst(artroutestepodslst, "/delete", serviceOfArtRouteStepOdsLst.Delete)
		// ArtRouteStepOdsLst查询多条
		RegisterSelectArtRouteStepOdsLst(artroutestepodslst, "/query", serviceOfArtRouteStepOdsLst.Select)
		// ArtRouteStepOdsLst查询一条
		RegisterSelectOneArtRouteStepOdsLst(artroutestepodslst, "/get", serviceOfArtRouteStepOdsLst.SelectOne)
		// ArtRouteStepOdsLst修改一条
		// RegisterUpdateOneArtRouteStepOdsLst(artroutestepodslst, "/updateone", serviceOfArtRouteStepOdsLst.UpdateOne)
		// ArtRouteStepOdsLst修改多条
		// RegisterUpdateArtRouteStepOdsLst(artroutestepodslst, "/update", serviceOfArtRouteStepOdsLst.Update)

		// StationOrder的路由组
		stationorder := party.Party("/stationorder")
		// StationOrder的服务实例
		var serviceOfStationOrder = svr.NewStationOrderService()
		// StationOrder插入一条
		// RegisterInsertOneStationOrder(stationorder, "/insertone", serviceOfStationOrder.InsertOne)
		// StationOrder插入多条
		// RegisterInsertStationOrder(stationorder, "/insert", serviceOfStationOrder.Insert)
		// StationOrder删除一条
		// RegisterDeleteOneStationOrder(stationorder, "/deleteone", serviceOfStationOrder.DeleteOne)
		// StationOrder删除多条
		// RegisterDeleteStationOrder(stationorder, "/delete", serviceOfStationOrder.Delete)
		// StationOrder查询多条
		RegisterSelectStationOrder(stationorder, "/query", serviceOfStationOrder.Select)
		// StationOrder查询一条
		RegisterSelectOneStationOrder(stationorder, "/get", serviceOfStationOrder.SelectOne)
		// StationOrder修改一条
		// RegisterUpdateOneStationOrder(stationorder, "/updateone", serviceOfStationOrder.UpdateOne)
		// StationOrder修改多条
		// RegisterUpdateStationOrder(stationorder, "/update", serviceOfStationOrder.Update)

	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
